==> haskell-skylighting-format-ansi-0.1-157-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-5OJEDNZaU2K24e2sVnsqMq
key:                  skylighting-format-ansi-0.1-5OJEDNZaU2K24e2sVnsqMq
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  4450601060f361790211c69ce2abb82d
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-5OJEDNZaU2K24e2sVnsqMq
depends:
    ansi-terminal-1.0-FJLEfMIg8XB3hMaFI0FBBX base-4.16.4.0
    binary-0.8.9.0 colour-2.3.6-9XZ0UIDKtRjEgaDeW5KVhY
    containers-0.6.5.1 skylighting-core-0.14.1.1-StYSO05jdQLxh9lh23vn
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-ansi-0.1-159-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-7xAnLa5OBnqI2pY88OK6s0
key:                  skylighting-format-ansi-0.1-7xAnLa5OBnqI2pY88OK6s0
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  c52f6037a33022d9716a66eed0729c7b
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-7xAnLa5OBnqI2pY88OK6s0
depends:
    ansi-terminal-1.0-FJLEfMIg8XB3hMaFI0FBBX base-4.16.4.0
    binary-0.8.9.0 colour-2.3.6-9XZ0UIDKtRjEgaDeW5KVhY
    containers-0.6.5.1 skylighting-core-0.14.1.1-DzYaf4zQUIH74HO9p2Dx5D
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
